parquetdb.core.parquetdb.LoadConfig
===================================

.. currentmodule:: parquetdb.core.parquetdb

.. autoclass:: LoadConfig

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LoadConfig.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~LoadConfig.batch_readahead
      ~LoadConfig.batch_size
      ~LoadConfig.fragment_readahead
      ~LoadConfig.fragment_scan_options
      ~LoadConfig.memory_pool
      ~LoadConfig.use_threads
   
   